# ResourceRuleGroup

Intersection rule to use when determing what should use a resource. IE devices with tags 'a' or 'v' and ... Currently only tag selection is supported. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**tags** | [**[SelectorTag]**](SelectorTag.md) | A list of machine tags for which a rule applies.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


